@@ -2,7 +2,6 @@
 #include <QString>
 #include <QChar>
 #include <QObject>
-#include <QTextStream>
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
 #include <QDebug>
@@ -16,7 +15,7 @@ HttpConnector::HttpConnector() {
     busy = false;
     http = new QNetworkAccessManager ();
     cache = new QNetworkDiskCache ();
-    #ifdef Q_WS_HILDON
+    #ifdef Q_WS_MAEMO_5
         cache->setCacheDirectory ("/opt/appdownloader/meta/cache/");
     #else
         cache->setCacheDirectory ("/tmp/.maemoclient/");
@@ -33,7 +32,7 @@ HttpConnector::HttpConnector(int _timeout,int _cacheSize) {
     busy = false;
     http = new QNetworkAccessManager ();
     cache = new QNetworkDiskCache ();
-    #ifdef Q_WS_HILDON
+    #ifdef Q_WS_MAEMO_5
         cache->setCacheDirectory ("/opt/appdownloader/meta/cache/");
     #else
         cache->setCacheDirectory ("/tmp/.maemoclient/");
@@ -116,11 +115,9 @@ void HttpConnector::readResponse () {
         qDebug()<<http->cookieJar()->cookiesForUrl(QUrl("https://maemo.org/"));
         if (bytes > 0) {
             response = reply->readAll();
-            emit getHttpResponseCode (reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt());
-            emit getResponseContent (false,new QString (response));
-            emit getRawData (false,response);
+            emit getResponseContent (response,reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt());
         } else {
-            emit getHttpResponseCode (reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt());
+            emit getResponseContent(QByteArray(),reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt());
         }
 
         reply->close();
@@ -136,11 +133,13 @@ void HttpConnector::readResponse () {
 /* private functions */
 
 void HttpConnector::setRequestTimeout() {
+    qDebug () << "timeout";
     disconnect (reply, SIGNAL(readChannelFinished()), this, SLOT(readResponse ()));
     disconnect (timer, SIGNAL(timeout()),this, SLOT (setRequestTimeout()));
     /* stop all requests when timeout occurs (see QTimer->timeout signal */
     reply->abort();
     busy=false;
+    emit getResponseContent (reply->readAll(),0);
+    reply->reset();
     emit isFree();
-    emit getResponseContent (true,new QString("Connection timeout!"));
 }
