@@ -10,7 +10,7 @@ class MaemoApplication : public QObject {
     public:
         // constructors
         MaemoApplication ();
-        MaemoApplication (QString,QString,QString, QString _rating=QString(""),QString _downloads="",QString _comments="",QString _version="",QString _pre="");
+        MaemoApplication (QString,QString,QString, QString _rating=QString(""),QString _downloads="",QString _comments="",QString _version="",QString _pre="",QString _bpre="");
         MaemoApplication (QString);
 
         //setting parameters
@@ -22,6 +22,7 @@ class MaemoApplication : public QObject {
         void setDownloads (QString _downloads);
         void setComments (QString _comments);
         void setPreview (QString _pre);
+        void setBigPreview (QString _bpre);
 
         //getting parameters
         QString getComments ();
@@ -32,6 +33,7 @@ class MaemoApplication : public QObject {
         QString getRating ();
         QString getDownloads ();
         QString getPreview ();
+        QString getBigPreview ();
 
         //output as QString
         QString toString ();
@@ -45,6 +47,7 @@ class MaemoApplication : public QObject {
             QString version;
             QString title;
             QString preview;
+            QString bigPreview;
 
  };
 
