@@ -77,7 +77,7 @@ void MaemoApplicationHandler::requestApplications(   QString OS,
     } else {
         qDebug () << "connector free - send request";
         connector->getRequest (url);
-        connect (connector, SIGNAL(getResponseContent(bool,QString*)),this,SLOT(parseAppListResponse(bool,QString*)));
+        connect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(parseAppListResponse(QByteArray,int)));
     }
 }
 
@@ -107,7 +107,7 @@ void MaemoApplicationHandler::requestApplicationData(QString uid) {
         }
         requestQueue->insert (requestQueue->begin(), new QueueElement (url,"","",QueueElement::DETAILS));
     } else {
-        connect (connector, SIGNAL(getResponseContent(bool,QString*)),this,SLOT(parseSingleAppResponse(bool,QString*)));
+        connect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(parseSingleAppResponse(QByteArray,int)));
         connector->getRequest(url);
     }
 
@@ -134,7 +134,7 @@ void MaemoApplicationHandler::requestCategories(QString OS) {
    else {
        qDebug () << "free, send request";
        connector->getRequest (url);
-       connect (connector, SIGNAL(getResponseContent(bool,QString*)),this,SLOT(parseCategoryResponse(bool,QString*)));
+       connect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(parseCategoryResponse(QByteArray,int)));
    }
 }
 
@@ -150,7 +150,7 @@ void MaemoApplicationHandler::requestImage (QString url, QString id, QString inf
         imageInUse->setURL(url);
         imageInUse->setID(id);
         imageInUse->setInfo(info);
-        connect (connector, SIGNAL(getRawData(bool,QByteArray)),this,SLOT(proceedImageResponse(bool,QByteArray)));
+        connect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(proceedImageResponse(QByteArray,int)));
         connector->getRequest(url);
     } else {
         if (!queueConnected) {
@@ -188,7 +188,7 @@ void MaemoApplicationHandler::requestLogin(QString uname, QString pw) {
 
     if (!connector->isBusy()) {
         connector->postRequest(QUrl ("https://maemo.org/"),postParams);
-        connect (connector,SIGNAL(getHttpResponseCode(int)),this,SLOT(loginResponse(int)));
+        connect (connector,SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(loginResponse(QByteArray,int)));
     }
     else {
         emit loggedIn (LoggedInConnectionError);
@@ -240,10 +240,10 @@ void MaemoApplicationHandler::proceedQueue () {
         if (q->getType()==QueueElement::IMAGE) {
             requestImage (q->getURL(),q->getID(),q->getInfo(),false);
         } else if (q->getType()==QueueElement::LIST) {
-            connect (connector, SIGNAL(getResponseContent(bool,QString*)),this,SLOT(parseAppListResponse(bool,QString*)));
+            connect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(parseAppListResponse(QByteArray,int)));
             connector->getRequest(q->getURL());
         } else if (q->getType()==QueueElement::DETAILS) {
-            connect (connector, SIGNAL(getResponseContent(bool,QString*)),this,SLOT(parseSingleAppResponse(bool,QString*)));
+            connect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(parseSingleAppResponse(QByteArray,int)));
             connector->getRequest(q->getURL());
         }
         delete q;
@@ -264,9 +264,8 @@ void MaemoApplicationHandler::proceedQueue () {
 
 void MaemoApplicationHandler::requestInstallFile (QString url) {
     connector->getRequest (url);
-    QTextStream out (stdout);
-    out <<"*********"+url << endl;
-    connect (connector, SIGNAL(getResponseContent(bool,QString*)),this,SLOT(proceedInstallFileResponse(bool,QString*)));
+    qDebug() <<"*********"+url << endl;
+    connect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(proceedInstallFileResponse(QByteArray,int)));
 }
 
 
@@ -274,10 +273,10 @@ void MaemoApplicationHandler::requestInstallFile (QString url) {
   response of the image-request is proceeded and QByteArray is transformed as an image
   @todo: check if image is in a valid format
   ***/
-void MaemoApplicationHandler::proceedImageResponse (bool err,QByteArray img)  {
-    disconnect (connector, SIGNAL(getRawData(bool,QByteArray)),this,SLOT(proceedImageResponse(bool,QByteArray)));
-    if (err) {
-        emit raiseError (new QString("Connection error"));
+void MaemoApplicationHandler::proceedImageResponse (QByteArray img, int httpCode)  {
+    disconnect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(proceedImageResponse(QByteArray,int)));
+    if (img.isEmpty()) {
+        emit raiseError (QString("Connection error"));
     } else {
         QPixmap *pic = new QPixmap();
         pic->loadFromData (img);
@@ -290,8 +289,8 @@ void MaemoApplicationHandler::proceedImageResponse (bool err,QByteArray img)  {
   proceed the install file and initiate the installation
   @todo: everything, just a bit more than a placeholder up to now
 ***/
-void MaemoApplicationHandler::proceedInstallFileResponse (bool error, QString *content) {
-    disconnect (connector, SIGNAL(getResponseContent(bool,QString*)),this,SLOT(proceedInstallFileResponse(bool,QString*)));
+void MaemoApplicationHandler::proceedInstallFileResponse (QByteArray content,  int) {
+    disconnect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(proceedInstallFileResponse(QByteArray,int)));
     #ifdef Q_WS_MAEMO_5
         QFile file ("/opt/appdownloader/meta/application.install");
     #else
@@ -301,7 +300,7 @@ void MaemoApplicationHandler::proceedInstallFileResponse (bool error, QString *c
             qDebug() << "fileerror";
         }
         QTextStream file_writer (&file);
-        file_writer << *content << endl;
+        file_writer << content << endl;
         file.close();
     #ifdef Q_WS_MAEMO_5
         const int suc = 1;
@@ -318,11 +317,9 @@ void MaemoApplicationHandler::proceedInstallFileResponse (bool error, QString *c
         }
         qDebug() << file.fileName();
         result = 1;
-        #ifdef Q_WS_MAEMO_5
-          result=hildon_mime_open_file(connection,"/opt/appdownloader/meta/application.install");
-        #endif
+        result=hildon_mime_open_file(connection,"/opt/appdownloader/meta/application.install");
         qDebug() << result;
-        if (result != suc) {http://talk.maemo.org/showthread.php?t=50753
+        if (result != suc) {
                 qDebug() << "did not work";
         }
     #endif
@@ -334,8 +331,8 @@ void MaemoApplicationHandler::proceedInstallFileResponse (bool error, QString *c
 
   **/
 
-void MaemoApplicationHandler::loginResponse(int code) {
-    disconnect (connector,SIGNAL(getHttpResponseCode(int)),this,SLOT(loginResponse(int)));
+void MaemoApplicationHandler::loginResponse(QByteArray,int code) {
+    disconnect (connector,SIGNAL(getResponseContent (QByteArray,int)),this,SLOT(loginResponse(QByteArray,int)));
     if (code==302) {
         emit loggedIn (LoggedIn);
     }
@@ -359,15 +356,15 @@ void MaemoApplicationHandler::commentApplication(int rating, QString comment, QS
         postData.append("_qf__net_nehmer_comments=&");
         postData.append("content="+comment+"&");
         postData.append("rating="+ QString::number(rating) +"&");
-        postData.append("midcom_helper_datamanager2_save=Send");
+        postData.append("subscribe=0&");
+        postData.append("midcom_helper_datamanager2_save=submit");
 
 
         // has to be added to the queue as well
         if (!connector->isBusy()) {
             connector->postRequest(QUrl ("https://maemo.org/downloads/product/Maemo5/"+applicationname),postData);
-            connect (connector,SIGNAL(getHttpResponseCode(int)),this,SLOT(commentResponse(int)));
+            connect (connector,SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(commentResponse(QByteArray,int)));
         }
-
     } else {
         emit commented (NotAuthorized);
     }
@@ -378,147 +375,108 @@ void MaemoApplicationHandler::commentApplication(int rating, QString comment, QS
 /**
   forward the response
   **/
-void MaemoApplicationHandler::commentResponse(int resp) {
-    disconnect (connector,SIGNAL(getHttpResponseCode(int)),this,SLOT(commentResponse(int)));
-    if (resp==302)
+void MaemoApplicationHandler::commentResponse(QByteArray, int resp) {
+    disconnect (connector,SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(commentResponse(QByteArray,int)));
+    if (resp==302) {
+        qDebug()<<"worked";
         emit commented(CommentSuccess);
-    else
+    }
+    else {
+        qDebug()<<"error: " +QString::number(resp);
         emit commented(CommentConnectionError);
+    }
 }
 
 /***
   xml of application list is parsed and a list of applications given back
   by the ready signal
  ***/
-void MaemoApplicationHandler::parseAppListResponse(bool error,QString *content) {
-    QTextStream out (stdout);
-    disconnect (connector, SIGNAL(getResponseContent(bool,QString*)),this,SLOT(parseAppListResponse(bool,QString*)));
-    if (error) {
-        out << error << endl;
-        if (mode=="testing") {
-            QList<MaemoApplication *> *appList = new QList<MaemoApplication *>();
-            appList->append(new MaemoApplication (QString("test1"),QString("e84d47088d0a11dc9a1f9b5a44045e485e48"),QString("test1"),QString("3"),QString("6000"),QString("3")));
-            appList->append(new MaemoApplication (QString("test2"),QString("64950be6721711deb1ed2953a550f700f700"),QString("test2"),QString("2"),QString("5000"),QString("1")));
-            appList->append(new MaemoApplication (QString("test3"),QString("e84d47088d0a11dc9a1f9b5a44045e485e48"),QString("test3"),QString("4"),QString("4000"),QString("5")));
-            appList->append(new MaemoApplication (QString("test4"),QString("64950be6721711deb1ed2953a550f700f700"),QString("test4"),QString("5"),QString("3000"),QString("0")));
-            appList->append(new MaemoApplication (QString("test5"),QString("e84d47088d0a11dc9a1f9b5a44045e485e48"),QString("test5"),QString("1"),QString("1000"),QString("2")));
-            emit applicationListReady (appList);
-        }
-        else {
-            emit raiseError (content);
-        }
+void MaemoApplicationHandler::parseAppListResponse(QByteArray content,int httpCode) {
+    disconnect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(parseAppListResponse(QByteArray,int)));
+    if (content.isEmpty()) {
+        qDebug () << "no response content: error code: " + QString::number(httpCode);
+        emit raiseError ("Connection error");
+        emit applicationListReady (new QList <MaemoApplication *> ());
     } else {
         xmlReader.clear();
-        xmlReader.addData (*content);
-
+        xmlReader.addData (content);
         int i=0;
-        QString uid;
-        QString name;
-        QString version;
-        QString comments;
-        QString downloads;
-        QString title;
-        QString rating;
-        QString pre;
-        QString bigPre;
 
+        MaemoApplication *app = new MaemoApplication();
         QList<MaemoApplication *> *appList = new QList<MaemoApplication *>();
         while (!xmlReader.atEnd()) {
            xmlReader.readNext();
             if (xmlReader.isStartElement()) {
                 if (xmlReader.name() == "id") {
                     xmlReader.readNext();
-                    out << "uid: " + xmlReader.text().toString() << endl;
-                    uid = xmlReader.text().toString();
+                    qDebug() << "uid: " + xmlReader.text().toString() << endl;
+                    app->setUid(xmlReader.text().toString());
                 }
                 else if (xmlReader.name() == "version") {
                     xmlReader.readNext();
-                    out << "version: " + xmlReader.text().toString() << endl;
-                    version = xmlReader.text().toString();
+                    qDebug() << "version: " + xmlReader.text().toString() << endl;
+                    app->setVersion( xmlReader.text().toString());
                 }
                 else if (xmlReader.name() == "comments") {
                     xmlReader.readNext();
-                    out << "comments: " + xmlReader.text().toString() << endl;
-                    comments = xmlReader.text().toString();
+                    qDebug() << "comments: " + xmlReader.text().toString() << endl;
+                    app->setComments(xmlReader.text().toString());
                 }
                 else if (xmlReader.name() == "downloads") {
                     xmlReader.readNext();
-                    out << "downloads: " + xmlReader.text().toString() << endl;
-                    downloads = xmlReader.text().toString();
+                    qDebug() << "downloads: " + xmlReader.text().toString() << endl;
+                    app->setDownloads(xmlReader.text().toString());
                 }
                 else if (xmlReader.name() == "score") {
                     xmlReader.readNext();
-                    out << "rating: " + xmlReader.text().toString() << endl;
-                    rating = xmlReader.text().toString();
+                    qDebug() << "rating: " + xmlReader.text().toString() << endl;
+                    app->setRating(xmlReader.text().toString());
                 }
                 else if (xmlReader.name() == "name") {
                     xmlReader.readNext();
-                    out << "title: " + xmlReader.text().toString() << endl;
-                    title = xmlReader.text().toString();
+                    qDebug() << "title: " + xmlReader.text().toString() << endl;
+                    app->setTitle(xmlReader.text().toString());
                 }
                 else if (xmlReader.name() == "smallpreviewpic1") {
                     xmlReader.readNext();
-                    out << "preview-url: " + xmlReader.text().toString() << endl;
-                    pre = xmlReader.text().toString();
+                    qDebug() << "preview-url: " + xmlReader.text().toString() << endl;
+                    app->setPreview(xmlReader.text().toString());
                 }
                 else if (xmlReader.name() == "previewpic1") {
                     xmlReader.readNext();
-                    bigPre = xmlReader.text().toString();
+                    app->setBigPreview(xmlReader.text().toString());
                 }
             } else if (xmlReader.isEndElement()) {
                 if (xmlReader.name() == "content") {
-                    out << "end: " + xmlReader.name().toString()<< endl;
-                    out << "************************************"<< endl;
-                    out << QString::number(i)<< endl;
-                    appList->append(new MaemoApplication (name,uid,title,rating,downloads,comments,version,pre,bigPre));
-                    out << QString::number(appList->length())<< endl;
-                    out << "************************************"<< endl;
-                    uid="";
-                    name="";
-                    version="";
-                    comments="";
-                    downloads="";
-                    title="";
-                    rating="";
-                    pre="";
-                    bigPre = "";
+                    qDebug() << "end: " + xmlReader.name().toString()<< endl;
+                    qDebug() << "************************************"<< endl;
+                    qDebug() << QString::number(i)<< endl;
+                    appList->append(app);
+                    qDebug() << QString::number(appList->length())<< endl;
+                    qDebug() << "************************************"<< endl;
+                    app=new MaemoApplication();
                     i++;
                 }
             }
         }
         emit applicationListReady (appList);
     }
-    delete content;
-
 }
 
 /***
   xml of single application is parsed and a MaemoApplication is returned
   ***/
-void MaemoApplicationHandler::parseSingleAppResponse(bool err, QString *content) {
+void MaemoApplicationHandler::parseSingleAppResponse(QByteArray content, int httpCode) {
     //@todo
-    disconnect (connector, SIGNAL(getResponseContent(bool,QString*)),this,SLOT(parseSingleAppResponse(bool,QString*)));
-    QTextStream out (stdout);
-    out << *content <<endl;
-    if (err) {
-        out << "error" << endl;
-        if (mode=="testing") {
-            MaemoApplicationDetails *appDetails = new MaemoApplicationDetails();
-            appDetails->setName ("TESTAPP");
-            appDetails->setRating ("4");
-            appDetails->setDesc ("THIS IS A TEST!! CONNECTION ERROR FORCES TO SHOW FAKED DATA! :)");
-            appDetails->setStatus ("stable");
-            appDetails->setDownloads ("1111");
-            appDetails->setInstallFile("a");
-            emit applicationDetailsReady(appDetails);
-
-        } else {
-            emit raiseError(content);
-        }
-        out << "error2" << endl;
+    disconnect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(parseSingleAppResponse(QByteArray,int)));
+    qDebug() << content <<endl;
+    if (content.isEmpty()) {
+        qDebug() << "error" << endl;
+        emit raiseError (QString("Connection error"));
+        emit applicationDetailsReady(new MaemoApplicationDetails ());
     } else {
         xmlReader.clear();
-        xmlReader.addData (*content);
+        xmlReader.addData (content);
         bool screenshots = false;
         MaemoApplicationDetails *appDetails = new MaemoApplicationDetails();
         MaemoComment *userComment;
@@ -577,7 +535,7 @@ void MaemoApplicationHandler::parseSingleAppResponse(bool err, QString *content)
                     }
                     else if (xmlReader.name()=="screenshots") {
                         screenshots=true;
-                        out << "start screenshots" << endl;
+                        qDebug()<< "start screenshots" << endl;
                     }
                     else if (xmlReader.name ()=="comments") {
                         xmlReader.readNext();
@@ -590,34 +548,34 @@ void MaemoApplicationHandler::parseSingleAppResponse(bool err, QString *content)
                                     if (false) {
                                         if (xmlReader.name () == "guid") {
                                             xmlReader.readNext();
-                                            out << "comment-uid " + xmlReader.text().toString ()<< endl;
+                                            qDebug() << "comment-uid " + xmlReader.text().toString ()<< endl;
                                             userComment -> setUid (xmlReader.text().toString ());
                                         }
                                         else if (xmlReader.name () == "author") {
                                             xmlReader.readNext();
                                             if (!xmlReader.text().toString ().isEmpty()) {
-                                                out << "comment-author " + xmlReader.text().toString ()<< endl;
+                                                qDebug() << "comment-author " + xmlReader.text().toString ()<< endl;
                                                 userComment -> setAuthor (xmlReader.text().toString ());
                                             }
                                         }
                                         else if (xmlReader.name() == "content") {
                                             xmlReader.readNext();
                                             if (!xmlReader.text().toString ().isEmpty()) {
-                                                out << "comment-content " + xmlReader.text().toString ()<< endl;
+                                                qDebug() << "comment-content " + xmlReader.text().toString ()<< endl;
                                                 userComment -> setContent (xmlReader.text().toString());
                                             }
                                         }
                                         else if (xmlReader.name() == "published") {
                                             xmlReader.readNext();
                                             if (!xmlReader.text().toString ().isEmpty()) {
-                                                out << "comment-published " + xmlReader.text().toString ()<< endl;
+                                                qDebug()<< "comment-published " + xmlReader.text().toString ()<< endl;
                                                 userComment -> setPublished (xmlReader.text().toString ());
                                             }
                                         }
                                         else if (xmlReader.name() == "rating") {
                                             xmlReader.readNext();
                                             if (!xmlReader.text().toString ().isEmpty()) {
-                                                out << "comment-rating " + xmlReader.text().toString ()<< endl;
+                                                qDebug() << "comment-rating " + xmlReader.text().toString ()<< endl;
                                                 userComment -> setRating (xmlReader.text().toString());
                                             }
                                         }
@@ -627,7 +585,7 @@ void MaemoApplicationHandler::parseSingleAppResponse(bool err, QString *content)
                             }
                             if (xmlReader.isEndElement()&&xmlReader.name()=="value") {
                                 if (!userComment->getAuthor().isEmpty() && !userComment->getContent().isEmpty()) {
-                                    out << "comment added" << endl;
+                                    qDebug() << "comment added" << endl;
                                     appDetails->addUserComment (userComment);
                                 }
                             }
@@ -648,17 +606,17 @@ void MaemoApplicationHandler::parseSingleAppResponse(bool err, QString *content)
                 }
             }
         }
-        out << appDetails->toString() << endl;
+        qDebug() << appDetails->toString() << endl;
         appDetails->setUnparsedComments (content);
         emit applicationDetailsReady(appDetails);
     }
 
 }
 
-void MaemoApplicationHandler::parseCommentsOnly (QString *com) {
-     QTextStream out (stdout);
+void MaemoApplicationHandler::parseCommentsOnly (QByteArray com, int preloadComments) {
+     int commentCount(0);
      xmlReader.clear();
-     xmlReader.addData (*com);
+     xmlReader.addData (com);
      MaemoComment *userComment;
      QList <MaemoComment*>* comments =  new QList <MaemoComment *> ();
      while (!xmlReader.atEnd()) {
@@ -667,42 +625,42 @@ void MaemoApplicationHandler::parseCommentsOnly (QString *com) {
         if (xmlReader.isStartElement()&&xmlReader.name()=="comments") {
              xmlReader.readNext();
              while (!(xmlReader.isEndElement()&&xmlReader.name()=="comments")) {
-                out << "1st while start" + xmlReader.name().toString()<< endl;
-                out << "1st while" + xmlReader.name().toString()<< endl;
+                qDebug() << "1st while start" + xmlReader.name().toString()<< endl;
+                qDebug() << "1st while" + xmlReader.name().toString()<< endl;
                 userComment = new MaemoComment();
                 if (xmlReader.name ()=="value"&&xmlReader.isStartElement()) {
                     while (!(xmlReader.isEndElement()&&xmlReader.name()=="value")) {
                         if (xmlReader.isStartElement()) {
                             if (xmlReader.name () == "guid") {
                                 xmlReader.readNext();
-                                out << "comment-uid " + xmlReader.text().toString ()<< endl;
+                                qDebug() << "comment-uid " + xmlReader.text().toString ()<< endl;
                                 userComment -> setUid (xmlReader.text().toString ());
                             }
                             else if (xmlReader.name () == "author") {
                                 xmlReader.readNext();
                                 if (!xmlReader.text().toString ().isEmpty()) {
-                                    out << "comment-author " + xmlReader.text().toString ()<< endl;
+                                    qDebug() << "comment-author " + xmlReader.text().toString ()<< endl;
                                     userComment -> setAuthor (xmlReader.text().toString ());
                                 }
                             }
                             else if (xmlReader.name() == "content") {
                                 xmlReader.readNext();
                                 if (!xmlReader.text().toString ().isEmpty()) {
-                                    out << "comment-content " + xmlReader.text().toString ()<< endl;
+                                    qDebug() << "comment-content " + xmlReader.text().toString ()<< endl;
                                     userComment -> setContent (xmlReader.text().toString());
                                 }
                             }
                             else if (xmlReader.name() == "published") {
                                 xmlReader.readNext();
                                 if (!xmlReader.text().toString ().isEmpty()) {
-                                    out << "comment-published " + xmlReader.text().toString ()<< endl;
+                                    qDebug() << "comment-published " + xmlReader.text().toString ()<< endl;
                                     userComment -> setPublished (xmlReader.text().toString ());
                                 }
                             }
                             else if (xmlReader.name() == "rating") {
                                 xmlReader.readNext();
                                 if (!xmlReader.text().toString ().isEmpty()) {
-                                    out << "comment-rating " + xmlReader.text().toString ()<< endl;
+                                    qDebug() << "comment-rating " + xmlReader.text().toString ()<< endl;
                                     userComment -> setRating (xmlReader.text().toString());
                                 }
                             }
@@ -712,8 +670,15 @@ void MaemoApplicationHandler::parseCommentsOnly (QString *com) {
                 }
                 if (xmlReader.isEndElement()&&xmlReader.name()=="value") {
                     if (!userComment->getAuthor().isEmpty() && !userComment->getContent().isEmpty()) {
-                        out << "comment added" << endl;
+                        qDebug() << "comment added" << endl;
                         comments->append (userComment);
+
+                        ++commentCount;
+
+                        if(preloadComments > 0 && commentCount >= preloadComments) {
+                            emit commentsParsed(comments);
+                            return;
+                        }
                     }
                 }
                 xmlReader.readNext();
@@ -725,15 +690,16 @@ void MaemoApplicationHandler::parseCommentsOnly (QString *com) {
  }
 
 
-void MaemoApplicationHandler::parseCategoryResponse(bool err, QString *content) {
-    disconnect (connector, SIGNAL(getResponseContent(bool,QString*)),this,SLOT(parseCategoryResponse(bool,QString*)));
-    if (err) {
-        emit raiseError (content);
+void MaemoApplicationHandler::parseCategoryResponse(QByteArray content,int httpCode) {
+    disconnect (connector, SIGNAL(getResponseContent(QByteArray,int)),this,SLOT(parseCategoryResponse(QByteArray,int)));
+    if (content.isEmpty()) {
+        emit raiseError (QString("Connection error"));
+        emit categoriesReady (new QList <MaemoCategory*> ());
     }
     else {
         qDebug () << "start parsing";
         xmlReader.clear();
-        xmlReader.addData(*content);
+        xmlReader.addData(content);
         QList <MaemoCategory*>* catList = new QList <MaemoCategory*>();
         QString id;
         QString name;
@@ -759,7 +725,7 @@ void MaemoApplicationHandler::parseCategoryResponse(bool err, QString *content)
         }
         emit categoriesReady(catList);
     }
-    delete content;
+
 }
 
 
@@ -814,7 +780,6 @@ QString MaemoApplicationHandler::queryBuilder ( QString OS,
 }
 
 QString MaemoApplicationHandler::formalizeQString (QString s) {
-    QTextStream out (stdout);
     s = s.replace ("\n"," ");
     return s;
 }
